'''
Functions and subgradients for DC functions supplied by the user.

As an example, f1 = Function 1 and f2 = Function 3 (5 commented) 
in Bagirov, A.M., Taheri, S., Joki, K., Karmitsa,N., Makela, M.M.: 
A new subgradient based method for nonsmooth DC programming, 
TUCS. Tech. rep., No. 1201, Turku Centre for Computer Science, 
Turku (2019)

Created on 14 Jan 2020

@author: napsu
'''
# Load library
import numpy as np

# Define f1
def f1(x):
    """ First component of nonsmooth DC function.
    
    First component function f1 of the DC function f=f1-f2.
    Supplied by the user.
    """
    f=(x.size + 1) * max(x*x)
    return f

# Define f2
def f2(x):
    """ Second component of nonsmooth DC function.
    
    Second component function f2 of the DC function f=f1-f2.
    Supplied by the user.
    """
    f=np.sum(x*x) # problem 3
    #f=np.sum(np.abs(x)) # problem 5
    return f

# Define df1
def df1(x):
    """ Subgradient of f1.
    
    Subgradient of the first component function f1 of the DC 
    function f=f1-f2. Supplied by the user.
    """
    i = np.argmax(x*x)
    g = np.zeros_like(x)
    g[i]=2.0*(x.size + 1)*x[i]
    return g

# Define df2
def df2(x):
    """ Subgradient of f2.
    
    Subgradient of the second component function f2 of the DC 
    function f=f1-f2. Supplied by the user.
    """
    g = 2.0*x # problem 3
    #g = np.ones_like(x) # problem 5
    #for i in range(x.size):
    #    if x[i]<0:
    #        g[i]=-1        
    
    return g

