'''
User specified initialization for the aggregate subgradient method.

Created on 15 Jan 2020

@author: napsu
'''
# Load library
import numpy as np

def init():
    """ Initialization for Aggregate subgradient method.
    
    Input:
        none;
        
    Output:
        n     - dimension of the problem;
        x     - starting point;
        eps   - optimality tolerance;
        mit   - maximum number of inner iterations;   
        tau   - proximity parameter, tau > 0;
        sig1  - decrease parameter for tau, sig1 in (0,1);
        delta - inner iteration tolerance, delta > 0; 
        sig2  - decrease parameter for delta, sig2 in (0,1];
        c1,c2 - line search parameters, 0 < c2 <= c1 < 1. 
            
    """
    
    # Starting point and dimension of the problem, supplied by the user.
    n = 100
    x = np.ones(n) # Vector of ones.
    #x = np.zeros(n) # Vector of zeros.
    #x = np.array([1.0, 2.0, 3.0]) # Create a row vector
    
    
    # Other parameters, default values are given as comments.
    eps = 10.0**(-5) # default = 10.0**(-5). 
    mit = 10000 # default = 1000.
    
    if n<200: # tau > 0, default = 10, if n<200,  
        tau = 10.0 #               50, otherwise.
    else:
        tau = 50.0
        
    delta = 10.0**(-3) # delta > 0, default = 10.0**(-7). 
    sig1 = 0.8 # sig1 in (0,1), default = 0.2.
    sig2 = 1.0 # sig2 in (0,1], default = 1.0.
    c1 = 0.2 # c1 in (0,1), default 0.2.
    c2 = 0.05 # c2 in (0,c1) default = 0.05.  
        
    return n,x,eps,mit,tau,delta,sig1,sig2,c1,c2